@@ -1,6 +1,6 @@
 #########################################################################
-# $Date: 2007-06-28 13:05:21 -0700 (Thu, 28 Jun 2007) $
-# $Revision: 120 $
+# $Date: 2007-06-29 11:10:50 -0700 (Fri, 29 Jun 2007) $
+# $Revision: 124 $
 # $Author: david.romano $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -10,7 +10,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.3.5');
+use version; our $VERSION = qv('0.3.6');
 
 use LWP::UserAgent;
 use Time::HiRes qw(time);
@@ -64,7 +64,7 @@ for ( keys %attributes ) {
     eval qq( 
         sub $_ {
             my \$self = shift;
-            return \$self->{$_} = shift if \@_;
+            return \$self->{$_} = shift if defined \$_[0];
             return \$self->{$_} if defined \$self->{$_};
             return \$self->{$_} = '$attributes{$_}';
         }
@@ -343,7 +343,7 @@ WWW::Facebook::API - Facebook API implementation
 
 =head1 VERSION
 
-This document describes WWW::Facebook::API version 0.3.5
+This document describes WWW::Facebook::API version 0.3.6
 
 =head1 SYNOPSIS
 
@@ -743,7 +743,7 @@ when an error is returned from the REST server.
 =item ua
 
 The L<LWP::UserAgent> agent used to communicate with the REST server.
-The agent_alias is initially set to "Perl-WWW-Facebook-API/0.3.5".
+The agent_alias is initially set to "Perl-WWW-Facebook-API/0.3.6".
 
 =back
 
@@ -969,20 +969,20 @@ Add tests to get better coverage.
   ---------------------------- ------ ------ ------ ------ ------ ------ ------
   File                           stmt   bran   cond    sub    pod   time  total
   ---------------------------- ------ ------ ------ ------ ------ ------ ------
-  blib/lib/WWW/Facebook/API.pm   82.0   64.4   34.3   88.9  100.0   88.1   75.2
-  .../WWW/Facebook/API/Auth.pm   81.2   22.2   20.0   80.0  100.0    1.5   69.4
-  ...WW/Facebook/API/Canvas.pm   46.2    0.0   16.7   50.0  100.0    0.9   46.4
-  ...WW/Facebook/API/Events.pm   92.3    n/a   33.3   75.0  100.0    0.8   85.4
-  .../WWW/Facebook/API/FBML.pm   88.9    n/a   33.3   66.7  100.0    0.9   81.8
-  ...b/WWW/Facebook/API/FQL.pm   96.0    n/a   33.3   85.7  100.0    0.7   89.5
-  .../WWW/Facebook/API/Feed.pm   92.3    n/a   33.3   75.0  100.0    1.1   85.4
-  ...W/Facebook/API/Friends.pm   88.9    n/a   33.3   66.7  100.0    0.8   81.8
-  ...WW/Facebook/API/Groups.pm   92.3    n/a   33.3   75.0  100.0    0.8   85.4
-  ...book/API/Notifications.pm   88.9    n/a   33.3   66.7  100.0    1.1   81.8
-  ...WW/Facebook/API/Photos.pm   80.0    n/a   33.3   50.0  100.0    0.7   73.6
-  ...W/Facebook/API/Profile.pm   85.7    n/a   33.3   60.0  100.0    0.8   78.7
-  ...WW/Facebook/API/Update.pm   96.0    n/a   33.3   85.7  100.0    0.7   89.5
-  ...WWW/Facebook/API/Users.pm   88.9    n/a   33.3   66.7  100.0    0.9   81.8
+  blib/lib/WWW/Facebook/API.pm   82.0   64.4   34.3   88.9  100.0   91.4   75.2
+  .../WWW/Facebook/API/Auth.pm   81.2   22.2   20.0   80.0  100.0    1.1   69.4
+  ...WW/Facebook/API/Canvas.pm   46.2    0.0   16.7   50.0  100.0    0.7   46.4
+  ...WW/Facebook/API/Events.pm   92.3    n/a   33.3   75.0  100.0    0.6   85.4
+  .../WWW/Facebook/API/FBML.pm   88.9    n/a   33.3   66.7  100.0    0.7   81.8
+  ...b/WWW/Facebook/API/FQL.pm   96.0    n/a   33.3   85.7  100.0    0.6   89.5
+  .../WWW/Facebook/API/Feed.pm   92.3    n/a   33.3   75.0  100.0    0.8   85.4
+  ...W/Facebook/API/Friends.pm   88.9    n/a   33.3   66.7  100.0    0.5   81.8
+  ...WW/Facebook/API/Groups.pm   92.3    n/a   33.3   75.0  100.0    0.6   85.4
+  ...book/API/Notifications.pm   88.9    n/a   33.3   66.7  100.0    0.8   81.8
+  ...WW/Facebook/API/Photos.pm   80.0    n/a   33.3   50.0  100.0    0.5   73.6
+  ...W/Facebook/API/Profile.pm   85.7    n/a   33.3   60.0  100.0    0.6   78.7
+  ...WW/Facebook/API/Update.pm   96.0    n/a   33.3   85.7  100.0    0.5   89.5
+  ...WWW/Facebook/API/Users.pm   88.9    n/a   33.3   66.7  100.0    0.6   81.8
   Total                          82.5   58.2   32.5   76.4  100.0  100.0   75.6
   ---------------------------- ------ ------ ------ ------ ------ ------ ------
 
@@ -996,6 +996,8 @@ Clayton Scott C<< http://www.matrix.ca >>
 
 David Leadbeater C<< http://dgl.cx >>
 
+Gisle Aas C<< none >>
+
 J. Shirley C<< <jshirley@gmail.com> >>
 
 Jim Spath C<< none >>
